==> haskell-hslua-packaging-2.3.1-144.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm
key:                  hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  0dab951acdeb1c11abb7da03231d2a60
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm
depends:
    base-4.18.2.1 containers-0.6.7
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-objectorientation-2.3.1-B9MwAAb5OzV1notznHofI0
    hslua-typing-0.1.1-4crtxjwFkdc2BMYn78fMvp mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-packaging-2.3.1-145-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-packaging.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS
key:                  hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  8aeac2f7bbdb43f8cd970a3fffb8989b
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS
depends:
    base-4.18.2.1 containers-0.6.7
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-objectorientation-2.3.1-BeXpt3VargyDZJB8AIbZnR
    hslua-typing-0.1.1-4nrS70YStomG6eM4zMy5zG mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
